#secret-id-map-mapbox-location-field {
    top: 0;
    bottom: 0;
    width: 100%;
    overflow: hidden;
    height: 350px;

}

.js-mapbox-input-location-field {
    visibility: visible;
    margin: 0.3%;
}

.mapboxgl-canvas {
    right: 1px;
    left: 1px;
}