{% include "default_django/input.html" %}
<div id='secret-id-map-mapbox-location-field' class='location-field-map'></div>
<div id='secret-id-geocoder-mapbox-location-field' class='location-field-geocoder'></div>
