{% extends 'admin/change_form.html' %}
{% block extrahead %}
    {% load mapbox_location_field_tags %}
    {% location_field_includes %}
    {% include_jquery %}
    {{ block.super }}
{% endblock %}
{% block footer %}
    {{ map_input_media }}
{% endblock %}